@@ -52,6 +52,7 @@ module.exports = extend(new Emitter(), {
   // application state, fetched every refresh
   actionItems: {},
   indexCounts: {},
+  channels: [], // array of { name: str, pinned: bool, lastUpdated: ts, hasNew: bool }
   user: {
     id: null,
     profile: {},
@@ -86,15 +87,52 @@ function addIssue (isUrgent, title, err, extraIssueInfo) {
   app.emit('update:issues')
 }
 
+function updateChannels (name, values) {
+  // upsert
+  var i
+  for (i = 0; i < app.channels.length; i++) {
+    if (app.channels[i].name === name) {
+      // immutable update - create a new object, so shouldUpdate works nicely in the channels list com
+      app.channels[i] = Object.assign({}, app.channels[i], values)
+      break
+    }
+  }
+  if (i === app.channels.length)
+    app.channels.push(Object.assign({ name: name }, values))
+
+  // sort
+  sortChannels()
+}
+
+function sortChannels () {
+  app.channels.sort(function (a, b) {
+    // put pinned at top
+    if (a.pinned !== b.pinned) {
+      if (a.pinned) return -1
+      if (b.pinned) return 1
+    }
+    // go by last updated
+    return b.lastUpdated - a.lastUpdated
+  })
+}
+
 function onPatchworkEvent (e) {
   if (e.type == 'index-change') {
     for (var k in e.counts)
       app.indexCounts[k] = e.counts[k]
     app.emit('update:indexCounts')
+    if (e.index.indexOf('channel-') === 0) {
+      updateChannels(e.index.slice('channel-'.length), { lastUpdated: Date.now() }) // TODO hasNew
+      app.emit('update:channels')      
+    }
   }
-  if (e.type == 'isread') {
+  else if (e.type == 'isread') {
     app.emit('update:isread', { key: e.key, value: e.value })
   }
+  else if (e.type == 'channelpinned') {
+    updateChannels(e.channel, { pinned: e.value })
+    app.emit('update:channels')
+  }
 }
 
 function pollPeers () {
@@ -122,6 +160,8 @@ function fetchLatestState (cb) {
   app.ssb.patchwork.getActionItems(done())
   app.ssb.patchwork.getIndexCounts(done())
   app.ssb.gossip.peers(done())
+  if (!app.channels.length)
+    app.ssb.patchwork.getChannels(done())
   done(function (err, data) {
     if (err) throw err.message
     app.user.id         = data[0].id
@@ -130,6 +170,10 @@ function fetchLatestState (cb) {
     app.actionItems     = data[3]
     app.indexCounts     = data[4]
     app.peers           = data[5]
+    if (data[6]) {
+      app.channels        = data[6]
+      sortChannels()
+    }
     app.isWifiMode      = require('./util').getPubStats(app.peers).hasSyncIssue
     app.user.profile    = app.users.profiles[app.user.id]
     app.user.needsSetup = !app.users.names[app.user.id]
