@@ -7,6 +7,7 @@ import NewsFeed from './views/newsfeed'
 import Inbox from './views/inbox'
 import Data from './views/data'
 import Msg from './views/msg'
+import Channels from './views/channels'
 import Profile from './views/profile'
 import WebView from './views/webview'
 import Sync from './views/sync'
@@ -25,17 +26,19 @@ function beforeNavigation (nextState) {
     window.history.replaceState({ vfScrollTops: vfScrollTops }, '')
   }
 }
-
 app.history.listenBefore(beforeNavigation)
+
 export default (
   <Router history={app.history}>
     <Route path="/" component={Layout}>
       <IndexRoute component={NewsFeed} />
-      <Route path="msg/:id" component={Msg} />
+      <Route path="newsfeed/channel/:channel" component={NewsFeed} />
+      <Route path="channels" component={Channels} />
       <Route path="inbox" component={Inbox} />
       <Route path="data" component={Data} />
       <Route path="profile" component={Profile} />
       <Route path="profile/:id" component={Profile} />
+      <Route path="msg/:id" component={Msg} />
       <Route path="webview/:id" component={WebView} />
       <Route path="sync" component={Sync} />
       <Route path="help/:section" component={Help} />
