@@ -7,8 +7,11 @@ import u from '../lib/util'
 
 export default class Msg extends React.Component {
   render() {
+    const id = this.props.params && this.props.params.id
     return <div id="msg">
-      <Thread id={this.props.params.id} live />
+      { id
+        ? <Thread id={id} live />
+        : <div style={{padding: 20, fontWeight: 300, textAlign:'center'}}>No thread selected.</div> }
     </div>
   }
 }
\ No newline at end of file
